@@ -7,6 +7,7 @@ from django.conf import urls as django_urls
 from django.contrib import admin
 from django.contrib import messages
 from django.contrib.admin.templatetags.admin_urls import admin_urlname
+from django.contrib.auth.models import Group
 from django.contrib.contenttypes.generic import GenericTabularInline
 from django.core.urlresolvers import reverse
 try:
@@ -20,6 +21,7 @@ from django.template import Template, Context
 from django.utils.translation import ugettext_lazy as _, ugettext
 from django import VERSION as DJANGO_VERSION
 
+from mezzanine.conf import settings
 from mezzanine.core.admin import TabularDynamicInlineAdmin
 
 from .forms import TicketAdminAutocompleteForm, ReportAdminAutocompleteForm
@@ -34,13 +36,13 @@ DEFAULT_LIST_PER_PAGE = 15
 
 
 class TipologyInline(TabularDynamicInlineAdmin):
-    extra = 3
     model = Tipology
+    fields = ('title', 'sites',)
 
 
 class MessageInline(TabularDynamicInlineAdmin):
     model = Message
-    fields = ('content', 'recipient',)
+    fields = ('content', )
 
 
 class ReportTicketInline(TabularDynamicInlineAdmin):
@@ -73,7 +75,7 @@ class CategoryAdmin(admin.ModelAdmin):
 
 # noinspection PyMethodMayBeStatic
 class TipologyAdmin(admin.ModelAdmin):
-    fields = ('title', 'category', 'priority', 'sites',)
+    fields = ('title', 'category', 'sites',)
     filter_horizontal = ('sites',)
     list_display = ['title', 'ld_category', 'ld_sites']
     list_filter = ['category']
@@ -110,9 +112,38 @@ class StatusListFilter(admin.ChoicesFieldListFilter):
 
 
 class SiteConfigurationAdmin(admin.ModelAdmin):
-    list_display = ['site', 'email_addrs_to', 'email_addr_from']
+    list_display = ['site', 'ld_emails', 'ld_admins', 'ld_operators',
+                    'ld_requesters']
     list_per_page = DEFAULT_LIST_PER_PAGE
+    search_fields = ['site__sitepermission__user__username']
 
+    @staticmethod
+    def format_usernames_by_group(obj, group):
+        return ', '.join(sorted(obj.get_usernames_by_group(group)))
+
+    def ld_requesters(self, obj):
+        return self.format_usernames_by_group(
+            obj, settings.HELPDESK_REQUESTERS)
+    ld_requesters.allow_tags = True
+    ld_requesters.short_description = _('Requesters')
+
+    def ld_operators(self, obj):
+        return self.format_usernames_by_group(obj, settings.HELPDESK_OPERATORS)
+    ld_operators.allow_tags = True
+    ld_operators.short_description = _('Operators')
+
+    def ld_admins(self, obj):
+        return self.format_usernames_by_group(obj, settings.HELPDESK_ADMINS)
+    ld_admins.allow_tags = True
+    ld_admins.short_description = _('Admins')
+
+    def ld_emails(self, obj):
+        result = (['(from) {}'.format(obj.email_addr_from)] +
+                  ['(to) {}'.format(email) for email in obj.email_addrs_to])
+        return '<hr>'.join(result)
+    ld_emails.allow_tags = True
+    ld_emails.short_description = _('Emails')
+    
 
 # noinspection PyProtectedMember
 class TicketAdmin(admin.ModelAdmin):
@@ -544,12 +575,7 @@ if DJANGO_VERSION[0] == 1 and DJANGO_VERSION[1] < 6:
     TicketAdmin.queryset = TicketAdmin.get_queryset
 
 
-class HeldeskUserAdmin(admin.ModelAdmin):
-    pass
-
-
 admin.site.register(Category, CategoryAdmin)
-admin.site.register(HelpdeskUser, HeldeskUserAdmin)
 admin.site.register(Report, ReportAdmin)
 admin.site.register(SiteConfiguration, SiteConfigurationAdmin)
 admin.site.register(Source, SourceAdmin)
